from __future__ import unicode_literals

from waldur_core.core import WaldurExtension


class AWSExtension(WaldurExtension):

    @staticmethod
    def django_app():
        return 'waldur_aws'

    @staticmethod
    def rest_urls():
        from .urls import register_in
        return register_in

    @staticmethod
    def get_cleanup_executor():
        from .executors import AWSCleanupExecutor
        return AWSCleanupExecutor



from django.apps import AppConfig


class AWSConfig(AppConfig):
    name = 'waldur_aws'
    verbose_name = "Waldur AWS EC2"
    service_name = 'Amazon'
    is_public_service = True

    def ready(self):
        from waldur_core.structure import SupportedServices

        from .backend import AWSBackend
        SupportedServices.register_backend(AWSBackend)



#!/usr/bin/env python
from setuptools import setup, find_packages


dev_requires = [
    'Sphinx==1.2.2',
]

tests_require = [
    'factory_boy==2.4.1',
]

install_requires = [
    'apache-libcloud>=1.1.0,<2.2.0',
    'waldur-core>=0.156.2',
]


setup(
    name='waldur-aws',
    version='0.11.4',
    author='OpenNode Team',
    author_email='info@opennodecloud.com',
    url='http://waldur.com',
    description='Waldur plugin for managing Amazon Web Services.',
    long_description=open('README.rst').read(),
    license='MIT',
    package_dir={'': 'src'},
    packages=find_packages('src', exclude=['*.tests', '*.tests.*', 'tests.*', 'tests']),
    install_requires=install_requires,
    zip_safe=False,
    extras_require={
        'dev': dev_requires,
        'test': tests_require,
    },
    entry_points={
        'waldur_extensions': (
            'waldur_aws = waldur_aws.extension:AWSExtension',
        ),
    },
    tests_require=tests_require,
    include_package_data=True,
    classifiers=[
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
